@@ -39,6 +39,7 @@ pub struct Options {
     pub main_result: MainResult,
     pub show_warnings: bool,
     pub edition: Edition,
+    pub debugger: Debugger,
 }
 
 impl Default for Options {
@@ -92,6 +93,7 @@ impl Default for Options {
             main_result: MainResult::Unit,
             show_warnings: false,
             edition: Edition::E2021,
+            debugger: Debugger::LLDB,
         }
     }
 }
@@ -169,3 +171,10 @@ impl IRust {
             || (!irust_cmd && !shell_cmd)
     }
 }
+
+#[allow(clippy::upper_case_acronyms)]
+#[derive(Deserialize, Serialize, Clone, Debug)]
+pub enum Debugger {
+    LLDB,
+    GDB,
+}
